Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(301)

Unified Diff: runtime/vm/stub_code.h

Issue 2503653002: JumpToFrame refactor (Closed)
Patch Set: code review Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/simulator_mips.cc ('k') | runtime/vm/stub_code.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/stub_code.h
diff --git a/runtime/vm/stub_code.h b/runtime/vm/stub_code.h
index 7d0dd14534fec8387dee5500a9ee8969e8d9137d..3a2cea016c318a54943937b67e170f47f91e6677 100644
--- a/runtime/vm/stub_code.h
+++ b/runtime/vm/stub_code.h
@@ -25,7 +25,8 @@ class Deserializer;
#if !defined(TARGET_ARCH_DBC)
#define VM_STUB_CODE_LIST(V) \
V(GetStackPointer) \
- V(JumpToExceptionHandler) \
+ V(JumpToFrame) \
+ V(RunExceptionHandler) \
V(UpdateStoreBuffer) \
V(PrintStopMessage) \
V(CallToRuntime) \
@@ -73,6 +74,7 @@ class Deserializer;
#define VM_STUB_CODE_LIST(V) \
V(LazyCompile) \
V(OptimizeFunction) \
+ V(RunExceptionHandler) \
V(FixCallersTarget) \
V(Deoptimize) \
V(DeoptimizeLazyFromReturn) \
@@ -138,8 +140,8 @@ class StubCode : public AllStatic {
// transitioning into dart code.
static bool InInvocationStub(uword pc);
- // Check if the specified pc is in the jump to exception handler stub.
- static bool InJumpToExceptionHandlerStub(uword pc);
+ // Check if the specified pc is in the jump to frame stub.
+ static bool InJumpToFrameStub(uword pc);
// Returns NULL if no stub found.
static const char* NameOfStub(uword entry_point);
« no previous file with comments | « runtime/vm/simulator_mips.cc ('k') | runtime/vm/stub_code.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698